Page_c76a3fcf https://linux-notes.org Unix/ Linux блог, на котором можно найти полезную информацию по настройке ОС и ПО. Mon, 20 Jan 2020 21:46:09 +0000 ru-RU hourly 1 https://wordpress.org/?v=6.7.2 Page_c76a3fcf https://linux-notes.org/konvertaciya-vmware-virtual-machine-virtualbox-v-unix-linux/ https://linux-notes.org/konvertaciya-vmware-virtual-machine-virtualbox-v-unix-linux/#respond Mon, 20 Jan 2020 21:45:26 +0000 https://linux-notes.org/?p=17589 Если честно, VMware мне больше нравится чем VirtualBox, но лицензию я не хочу покупать для домашнего использования. По этому, выбор пал на то, чтобы перейти с VMware Fusion на VirtualBox. Для этого дела, мне пришлось зарегистрироваться на официальном сайте, заполнить данные. Но сразу я скачать не смог, возникли трудности с ПО и мне нужно было обратиться в поддержку. Поддержка решала данный вопрос около недели, но все решилось и я смог загрузить DMG на свой мак.

The post Конвертация VMware virtual machine -> VirtualBox в Unix/Linux first appeared on linux-notes.org.]]>

Если честно, VMware мне больше нравится чем VirtualBox, но лицензию я не хочу покупать для домашнего использования. По этому, выбор пал на то, чтобы перейти с VMware Fusion на VirtualBox. Для этого дела, мне пришлось зарегистрироваться на официальном сайте, заполнить данные. Но сразу я скачать не смог, возникли трудности с ПО и мне нужно было обратиться в поддержку. Поддержка решала данный вопрос около недели, но все решилось и я смог загрузить DMG на свой мак.

Конвертация VMware virtual machine -> VirtualBox на MacOS

Для начала, заходим на официальный сайт и качаем утилиту под названием «ovftool».

Установить DMG на МасОС через CLI можно так:

Установка dmg пакетов через CLI (командную строку) в MacOS X

Монтирование dmg образов через CLI (командную строку) в MacOS X

При использовании мака, утилита установится по следующему пути:

/Applications/VMware\ OVF\ Tool/ovftool

Чтобы получить помощь, выполните:

$ /Applications/VMware\ OVF\ Tool/ovftool -h
Usage: ovftool [options] <source> [<target>]
where
<source>: Source URL locator to an OVF package, VMX file, or virtual machine in
          vCenter or on ESX Server.
<target>: Target URL locator which specifies either a file location, or a
          location in the vCenter inventory or on an ESX Server.

If <target> is not specified, information about the source is displayed to the
console.

Options:
     --acceptAllEulas            : Accept all end-user licenses agreements
                                   without being prompted.
     --allowAllExtraConfig       : Whether we allow all the ExtraConfig
                                   options. These options are a security risk
                                   as they control low-level and potential
                                   unsafe options on the VM.
     --allowExtraConfig          : Whether we allow ExtraConfig options. These
                                   options are a security risk as they control
                                   low-level and potential unsafe options on
                                   the VM.
     --annotation                : Add annotation to vi, vmx, vapprun, vCloud,
                                   OVF, and OVA source locators
     --authdPortSource           : Use this to override default vmware authd
                                   port (902) when using a host as source.
     --authdPortTarget           : Use this to override default vmware authd
                                   port (902) when using a host as target.
     --chunkSize                 : Specifies the chunk size to use for files in
                                   a generated OVF package. The default is not
                                   to chunk. The chunk size without unit is
                                   assumed to be in megabytes. Accepted units
                                   are b, kb, mb, gb; e.g., 2gb or 100kb.
     --compress                  : Compress the disks in an OVF package. Value
                                   must be between 1 and 9. 1 is the fastest,
                                   but gives the worst compression, whereas 9
                                   is the slowest, but gives the best
                                   compression.
     --computerName              : Sets the computer name in the guest for a VM
                                   using the syntax --computerName:<VM
                                   ID>=<value>. Only applies to vCloud targets
                                   version 5.5 or newer.
     --coresPerSocket            : Specifies the distribution of the total
                                   number of CPUs over a number of virtual
                                   sockets using the syntax
                                   --coresPerSocket:<VM ID>=<value>. Only
                                   applies to vCloud targets version 5.5 or
                                   newer.
 -ds/--datastore                 : Target datastore name for a VI locator.
     --decodeBase64              : Decode option values with Base64.
     --defaultStorageProfile     : The storage profile for all VMs in the OVF
                                   package. The value should be an SPBM profile
                                   ID. Only applies to VI targets version 5.5
                                   or newer.
     --defaultStorageRawProfile  : The storage profile for all VMs in the OVF
                                   package. The value should be raw SPBM
                                   profile. The value will overwrite that in
                                   --defaultStorageProfile. Only applies to VI
                                   targets version 5.5 or newer.
     --deploymentOption          : Selects what deployment option to use (if
                                   the source OVF package supports multiple
                                   options.)
     --disableVerification       : Skip validation of signature and
                                   certificate.
 -dm/--diskMode                  : Select target disk format. Supported formats
                                   are: monolithicSparse, monolithicFlat,
                                   twoGbMaxExtentSparse, twoGbMaxExtentFlat,
                                   seSparse (VI target), eagerZeroedThick (VI
                                   target), thin (VI target), thick (VI
                                   target), sparse, and flat
     --diskSize                  : Sets the size of a VM disk in megabytes
                                   using the syntax --diskSize:<VM ID>,<disk
                                   instance ID>=<value>. Only applies to vCloud
                                   targets version 5.5 or newer.
     --eula                      : EULA to be inserted in the first virtual
                                   system or virtual system collection in the
                                   OVF. If the EULA is in a file, use the
                                   option --eula@=filename instead.
     --exportDeviceSubtypes      : Enables export of resource subtype for
                                   CD/Floppy/Parallel/Serial devices. This can
                                   limit portability as not all device backings
                                   are supported on all hypervisors. The
                                   default is false.
     --exportFlags               : Specifies one or more export flags to
                                   control what gets exported. The supported
                                   values for VI sources are mac, uuid, and
                                   extraconfig. Supported value for vCloud
                                   sources are preserveIdentity. One or more
                                   options can be provided, separated by
                                   commas.
     --extraConfig               : Sets an ExtraConfig element for all
                                   VirtualHardwareSections. The syntax is
                                   --extraConfig:<key>=<value>. Applies to vi,
                                   vmx, vapprun, vCloud, ovf, and ova source
                                   locators.
     --fencedMode                : If a parent network exists on the vCloud
                                   target, this property specifies the
                                   connectivity to the parent. Possible values
                                   are bridged, isolated, and natRouted.
 -h /--help                      : Prints this message.
     --hideEula                  : In OVF probe mode, hides the EULA.
     --ipAllocationPolicy        : IP allocation policy for a deployed OVF
                                   package.Supported values are: dhcpPolicy,
                                   transientPolicy, fixedPolicy,
                                   fixedAllocatedPolicy.
     --ipProtocol                : Select what IP protocol to use (IPv4, IPv6).
     --lax                       : Relax OVF specification conformance and
                                   virtual hardware compliance checks. Use only
                                   if you know what you are doing.
     --locale                    : Selects locale for target.
     --machineOutput             : Output OVF Tool messages in a machine
                                   friendly manner.
     --makeDeltaDisks            : Build delta disk hierarchy from the given
                                   source locator.
     --maxVirtualHardwareVersion : The maximal virtual hardware version to
                                   generate.
     --memorySize                : Sets the memory size in megabytes of a VM
                                   using the syntax --memorySize:<VM
                                   ID>=<value>. Only applies to vCloud targets
                                   version 5.5 or newer.
 -n /--name                      : Specifies target name (defaults to source
                                   name).
     --net                       : Set a network assignment in the deployed OVF
                                   package. A network assignment is set using
                                   the syntax --net:<OVF name>=<target name>.
                                   If the target is vCloud 5.5 or newer, a
                                   fence mode can also be specified using the
                                   syntax --net:<OVF name>=<target name>,<fence
                                   mode>. Possible fence mode values are:
                                   bridged, isolated, and natRouted.
 -nw/--network                   : Target network for a VI deployment.
     --nic                       : Specifies NIC configuration in a VM using
                                   the syntax --nic:<VM ID>,<index>=<OVF net
                                   name>,<isPrimary>,<ipAddressingMode>,<ipAddress>.
                                   Possible values for ipAddressingMode are:
                                   DHCP, POOL, MANUAL, and NONE. ipAddress is
                                   optional and should only be used when
                                   ipAddressingMode is set to MANUAL. Only
                                   applies to vCloud targets version 5.5 or
                                   newer.
     --noDisks                   : Disable disk conversion.
     --noImageFiles              : Do not include image files in destination.
     --noSSLVerify               : Skip SSL verification for VI connections.
     --numberOfCpus              : Sets the number of CPUs for a VM using the
                                   syntax --numberOfCpus:<VM ID>=<value>. Only
                                   applies to vCloud targets version 5.5 or
                                   newer.
 -o /--overwrite                 : Force overwrites of existing files.
     --powerOffSource            : Ensures a VM/vApp is powered off before
                                   importing from a VI source.
     --powerOffTarget            : Ensures a VM/vApp is powered off before
                                   overwriting a VI target.
     --powerOn                   : Powers on a VM/vApp deployed on a VI target.
     --privateKey                : Sign OVF package with the given private key
                                   (.pem file). The file must contain a private
                                   key and a certificate.
     --privateKeyPassword        : Password for the private key. Should be used
                                   in conjunction with privateKey if the
                                   private key requires password
                                   authentication. If required and not
                                   specified, the tool will prompt for the
                                   password.
     --prop                      : Set a property in the deployed OVF package.
                                   A property is set using the syntax
                                   --prop:<key>=<value>.
     --proxy                     : Proxy used for HTTP[S] access.
     --proxyNTLMAuth             : Enable NTLM authentication for proxy.
 -q /--quiet                     : No output to screen except errors.
     --schemaValidate            : Validate OVF descriptor against OVF schema.
     --shaAlgorithm              : Select SHA digest algorithm when creating
                                   OVF package. Supported values are SHA1,
                                   SHA256 and SHA512. Default value is SHA256.
     --skipManifestCheck         : Skip validation of OVF package manifest.
     --skipManifestGeneration    : Skip generation of OVF package manifest.
     --sourcePEM                 : File path to PEM formatted file used to
                                   verify VI connections.
     --sourceSSLThumbprint       : SSL fingerprint of SOURCE. OVF Tool verifies
                                   the SSL fingerprint it gets from SOURCE if
                                   the value is set.
 -st/--sourceType                : Explicitly express that source is OVF, OVA,
                                   VMX, VI, vCloud, ISO, FLP, vApprun
     --sslCipherList             : Use this to override default OpenSSL ciphers
                                   suite.
     --sslVersion                : Use this to set preferred TLS/SSL version
                                   for HTTPS connections. The valid values are
                                   as following:
                                     TLSv1_0: Set preferred TLS/SSL version to
                                   TLSv1.0.
                                     TLSv1_1: Set preferred TLS/SSL version to
                                   TLSv1.1.
                                     TLSv1_2: Set preferred TLS/SSL version to
                                   TLSv1.2.
     --storageProfile            : Sets the storage profile for a VM using the
                                   syntax --storageProfile:<VM ID>=<value>.
                                   Only applies to vCloud targets version 5.5
                                   or newer.
     --targetPEM                 : File path to PEM formatted file used to
                                   verify VI connections.
     --targetSSLThumbprint       : SSL fingerprint of TARGET. OVF Tool verifies
                                   the SSL fingerprint it gets from TARGET if
                                   the value is set.
 -tt/--targetType                : Explicitly express that target is OVF, OVA,
                                   VMX, VI, vCloud, ISO, FLP, vApprun
     --vCloudTemplate            : Create only a vApp template. Default value
                                   is false
     --vService                  : Set a vService assignment in the deployed
                                   OVF package. A vService assignment is set
                                   using the syntax
                                   --vService:<dependencyId>=<providerId>.
     --verifyOnly                : Do not upload the source but only verify it
                                   against the target host. Applies to VI 4
                                   targets only.
 -v /--version                   : Prints the version of this tool.
     --viCpuResource             : Specify the CPU resource settings for
                                   VI-locator targets. The syntax is
                                   --viCpuResource=<shares>:<reservation>:<limit>.
     --viMemoryResource          : Specify the CPU resource settings for
                                   VI-locator targets. The syntax is
                                   --viMemoryResource=<shares>:<reservation>:<limit>.
 -vf/--vmFolder                  : Target VM folder in VI inventory (relative
                                   to datacenter).

For more help, type: --help <topic>, where topics are:
 locators    : For detailed source and destination locator syntax
 examples    : For examples of use
 config      : For syntax of configuration files
 debug       : For debug purpose
 integration : For a list of options primarily used when ovftool is exec'ed
               from another tool or shellscript.

Использование довольно простое, например я использовал:

$ /Applications/VMware\ OVF\ Tool/ovftool /Users/captain/VirtualBox\ VMs/Windows\ 7/Windows\ 7\ x64.vmwarevm/Windows\ 7\ x64.vmx /Users/captain/VirtualBox\ VMs/Windows\ 7/Windows\ 7/windows_7.ovf
Opening VMX source: /Users/captain/VirtualBox VMs/Windows 7/Windows 7 x64.vmwarevm/Windows 7 x64.vmx
Opening OVF target: windows_7.ovf
Writing OVF package: windows_7.ovf
Disk progress: 5%

В папке которой был выполнен экспорт файлов, появятся файлы. Кликаем по файлу с «*.ovf» (у меня это windows_7.ovf):

Смотрим что хотим импортить, если что — изменяем и нажимаем на «Import». Импортинг занял 2 минуты у меня для Виндовс 7.

С приходом 64-битной ОС в МакОС, стало сложнее использование старые утилиты. Новые тоже не просто найти бесплатно. По этому, пришлось уйти с VMware…

Конвертация VMware virtual machine -> VirtualBox на Linux

В принципе — все тоже самое что я делал в МакОС, только нужно скачать бинарный файл для Linux-а. Если у кого-то возникнут трудность — смогу помочь! Пишите в комментариях возникшие ошибки и при первой возможности — отпишусь.

Вот и все, статья «Конвертация VMware virtual machine -> VirtualBox в Unix/Linux» завершена.

The post Конвертация VMware virtual machine -> VirtualBox в Unix/Linux first appeared on linux-notes.org.]]>
https://linux-notes.org/konvertaciya-vmware-virtual-machine-virtualbox-v-unix-linux/feed/ 0
Page_c76a3fcf https://linux-notes.org/ispravlyaem-there-was-an-error-while-executing-vboxmanage-a-cli-used-by-vagrant-v-virtualbox-i-vagrant/ https://linux-notes.org/ispravlyaem-there-was-an-error-while-executing-vboxmanage-a-cli-used-by-vagrant-v-virtualbox-i-vagrant/#respond Sun, 22 Jan 2017 17:33:26 +0000 http://linux-notes.org/?p=11565 Исправляем «There was an error while executing `VBoxManage`, a CLI used by Vagrant» в VirtualBox и Vagrant При работе с vagrant, получил ошибку и в своей статье я расскажу как можно ее исправить. Ошибка выглядит следующим образом: $ vagrant up Bringing machine 'default' up with 'virtualbox' provider... ==> default: Clearing any previously set network interfaces... […]

The post Исправляем «There was an error while executing `VBoxManage`, a CLI used by Vagrant» в VirtualBox и Vagrant first appeared on linux-notes.org.]]>

Исправляем «There was an error while executing `VBoxManage`, a CLI used by Vagrant» в VirtualBox и Vagrant

При работе с vagrant, получил ошибку и в своей статье я расскажу как можно ее исправить. Ошибка выглядит следующим образом:

$ vagrant up          

Bringing machine 'default' up with 'virtualbox' provider...
==> default: Clearing any previously set network interfaces...
There was an error while executing `VBoxManage`, a CLI used by Vagrant
for controlling VirtualBox. The command and stderr is shown below.

Command: ["hostonlyif", "create"]

Stderr: 0%...
Progress state: NS_ERROR_FAILURE
VBoxManage: error: Failed to create the host-only adapter
VBoxManage: error: VBoxNetAdpCtl: Error while adding new interface: failed to open /dev/vboxnetctl: No such file or directory
VBoxManage: error: Details: code NS_ERROR_FAILURE (0x80004005), component HostNetworkInterfaceWrap, interface IHostNetworkInterface
VBoxManage: error: Context: "RTEXITCODE handleCreate(HandlerArg *)" at line 71 of file VBoxManageHostonly.cpp

Т.е при вызове «vagrant up» отказался собираться VagrantFile.

Исправляем «There was an error while executing `VBoxManage`, a CLI used by Vagrant» в VirtualBox и Vagrant

У меня ОС — Mac OS X и я использую Vagrant с подключенной виртуализацией VirtualBox. Но иногда не все проходит гладко.

Решение простое — это перезапустить службу VirtualBox, статья как это можно сделать тут:
Перезапуск VirtualBox в Unix/Linux

Вот таким образом я решил и устранил свою проблему.

The post Исправляем «There was an error while executing `VBoxManage`, a CLI used by Vagrant» в VirtualBox и Vagrant first appeared on linux-notes.org.]]>
https://linux-notes.org/ispravlyaem-there-was-an-error-while-executing-vboxmanage-a-cli-used-by-vagrant-v-virtualbox-i-vagrant/feed/ 0
Page_c76a3fcf https://linux-notes.org/perezapusk-virtualbox-v-unix-linux/ https://linux-notes.org/perezapusk-virtualbox-v-unix-linux/#respond Mon, 24 Oct 2016 00:11:13 +0000 http://linux-notes.org/?p=11190 Перезапуск VirtualBox в Unix/Linux Не понятно почему, но у меня перестал работать virtualbox при попытке собрать образ centos через Vagrant. Потребовалось некоторое время на гугление и решение данной проблемы. Перезапуск VirtualBox в Linux Чтобы исправить данную проблему, нужно запустить: $ sudo /Library/StartupItems/VirtualBox/VirtualBox restart Или: $ sudo launchctl load /Library/LaunchDaemons/org.virtualbox.startup.plist Так же, можно попробовать: # modprobe vboxnetadp […]

The post Перезапуск VirtualBox в Unix/Linux first appeared on linux-notes.org.]]>

Перезапуск VirtualBox в Unix/Linux

Не понятно почему, но у меня перестал работать virtualbox при попытке собрать образ centos через Vagrant. Потребовалось некоторое время на гугление и решение данной проблемы.

Перезапуск VirtualBox в Linux

Чтобы исправить данную проблему, нужно запустить:

$ sudo /Library/StartupItems/VirtualBox/VirtualBox restart

Или:

$ sudo launchctl load /Library/LaunchDaemons/org.virtualbox.startup.plist

Так же, можно попробовать:

# modprobe vboxnetadp

Перезапуск VirtualBox в MacOSX.

Я решил проблему следующим образом:

$ sudo /Library/Application\ Support/VirtualBox/LaunchDaemons/VirtualBoxStartup.sh restart
Unloading VBoxDrv.kext
Loading VBoxDrv.kext
Loading VBoxUSB.kext
Loading VBoxNetFlt.kext
Loading VBoxNetAdp.kext
$

Вот и все, статья «Перезапуск VirtualBox в Unix/Linux» завершена.

The post Перезапуск VirtualBox в Unix/Linux first appeared on linux-notes.org.]]>
https://linux-notes.org/perezapusk-virtualbox-v-unix-linux/feed/ 0
Page_c76a3fcf https://linux-notes.org/sohranyaem-vse-rezervny-e-kopii-v-dropbox/ https://linux-notes.org/sohranyaem-vse-rezervny-e-kopii-v-dropbox/#comments Mon, 10 Aug 2015 21:48:54 +0000 http://linux-notes.org/?p=3581 Сохраняем все резервные копии в Dropbox В своей статье «Сохраняем все резервные копии в Dropbox» я расскажу как можно создавать бэкапы и сохранять их в Dropbox, на готовом примере — это Debian 8 покажу как это работает. Для создания бэкапов, я установлю утилиту backup-manager, для этого выполняем команду: Для Centos/Fedora/RHEL: # yum install backup-manager Для Debian/Mint/Ubuntu: # apt-get […]

The post Сохраняем все резервные копии в Dropbox first appeared on linux-notes.org.]]>

Сохраняем все резервные копии в Dropbox

В своей статье «Сохраняем все резервные копии в Dropbox» я расскажу как можно создавать бэкапы и сохранять их в Dropbox, на готовом примере — это Debian 8 покажу как это работает.

Для создания бэкапов, я установлю утилиту backup-manager, для этого выполняем команду:

Для Centos/Fedora/RHEL:

# yum install backup-manager

Для Debian/Mint/Ubuntu:

# apt-get install backup-manager

В ходе установке, вас попросят ввести место для сохранения всех ваших бекапов, я прописал:

выбор директории для хранения бэкапов backup-manager

выбор директории для хранения бэкапов backup-manager

Далее, необходимо прописать все директории для которых нужно делать бэкапы, для меня важны лишь 2 директории:

выбор директорий для создания бэкапов backup-manager

выбор директорий для создания бэкапов backup-manager

После установки можно внести изменения в конфигурационный файл:

# vim /etc/backup-manager.conf

В данном файле, есть комментарии и они помогают в настройке данной утилиты, но я вынес основные строки для изменения (редактирования):

# Говорит утилите чтобы она запускалась каждый день 
export BM_DAILY_CRON="true"
# Путь, где будут лежать ваши бэкапы
export BM_REPOSITORY_ROOT="/var/backup-manager"
# Папка для временных файлов, указываем путь
export BM_TEMP_DIR="/var/tmp" 
#export BM_ARCHIVE_FREQUENCY="daily"
# Создание бэкапов и так же всех БД mysql
export BM_ARCHIVE_METHOD="tarball-incremental mysql"
# Путь без пробелов в названии, у меня будет создаваться бэкапы etc и home:
export BM_TARBALL_DIRECTORIES="/etc /home"
#ИЛИ
# Можно так же использовать массив, в нем прописываем нужны папки для бэкапов:
declare -a BM_TARBALL_TARGETS
BM_TARBALL_TARGETS[0]="/etc"
BM_TARBALL_TARGETS[1]="/home"
BM_TARBALL_TARGETS[2]="/root"
export BM_TARBALL_TARGETS

# Настройка для mysql. Я ее использую, так же есть и др БД
# Прописываем пользователя от которого будет создаваться бэкап БД, у меня это root 
export BM_MYSQL_ADMINLOGIN="root"
# И пароль для пользователя, у меня это root
export BM_MYSQL_ADMINPASS="SeCuRePaSsWoRd"
# Прописываем хост, на котором работает mysql
export BM_MYSQL_HOST="localhost"
# Прописываем порт на котором работает сервер БД mysql
export BM_MYSQL_PORT="3306"

Это не весь конфиг, а только основная его часть, остальное я не трогал и оставил все как есть. Следующим действием я проверю работает ли backup-manager корректно (создает ли бэкапы), для этого запустим его из командной строки и проверим результат:

# backup-manager -v

/var/backup-manager/debian-etc.20150810.master.tar.gz: ok (2M, a11380fc4b446eeee928b93e5688b6b3)
/var/backup-manager/debian-home.20150810.master.tar.gz: ok (10M, d1c596ba77b74d52b4f33f9537b4f3a0)
/var/backup-manager/debian-root.20150810.master.tar.gz: ok (1M, 2cd19c3cba82c721b4ad53c19ec338f3)
Creating a default MySQL client configuration file: /root/.backup-manager_my.cnf
/var/backup-manager/debian-all-mysql-databases.20150810.sql.bz2: ok (2M, 2458cd46a0124328a31c8160e1ee364d)
Error reported by backup-manager-upload for method "scp", check "/var/tmp/bmu-log.VGW6BW".

Проверим наличие бекапов:

# ls -l /var/backup-manager/

total 11696
-rw-rw---- 1 root root 284 Aug 10 05:17 debian-20150810.md5
-rw-rw---- 1 root root 1150009 Aug 10 05:17 debian-all-mysql-databases.20150810.sql.bz2
-rw-rw---- 1 root root 1340334 Aug 10 05:17 debian-etc.20150810.master.tar.gz
-rw------- 1 root root 64020 Aug 10 05:17 debian-etc.incremental.bin
-rw-rw---- 1 root root 9373958 Aug 10 05:17 debian-home.20150810.master.tar.gz
-rw------- 1 root root 26494 Aug 10 05:17 debian-home.incremental.bin
-rw-rw---- 1 root root 2015 Aug 10 05:17 debian-root.20150810.master.tar.gz
-rw------- 1 root root 382 Aug 10 05:17 debian-root.incremental.bin

И так, видно что все работает хорошо и бэкапы созданы. Утилита backup-manager будет выполнять создание бэкапов 1 раз в день, т.к установлена опция BM_DAILY_CRON=»true» в конфиге. Собственно бэкапы создаются и теперь нужно настроить чтобы они отправлялись в Dropbox.

Я крайне рекомендую создать аккаунт в Dropbox для сохранения всех бэкапов. После регистрации,  необходимо скачать и установить клиент для работы dropbox на сервер.

Определяем разрядность своей ОС, для этого есть команда:

# uname -a

Для 64-битных ОС, используйте:

# wget -O - "http://www.dropbox.com/download/?plat=lnx.x86_64" | tar xvzf - -C /root

Для 32-битных ОС, используйте:

# wget -O - "http://www.dropbox.com/download/?plat=lnx.x86" | tar xvzf - -C /root

После такой установки, необходимо произвести авторизацию чтобы начать работать с Dropbox, для этого существует скрипт который стоит запустить:

# /root/.dropbox-dist/dropboxd

Нужно авторизоваться в сам DropBox. Далее, я нашел готовое решение для запуска Dropbox, для этого скачиваем и выставляем права на готовый скрипт:

# wget -O /etc/init.d/dropbox "https://gist.github.com/bezumkin/6712351/raw/108fc8af551cb4fdf7cdd08b891a45f405d283dc/dropbox" && sudo chmod +x /etc/init.d/dropbox

ВНИМАНИЕ! Нужно заменить в данном скрипте (который находится в /etc/init.d/dropbox) пользователя от которого будут запущен дропбокс, а так же юзера от которого он будет работать (заменяем «user1» и «user2» на свои). Незабываем сохраниться и так же, добавим данный скрипт ( службу) в автозагрузку ОС:

# update-rc.d dropbox defaults 6

И так, все готово, теперь пришло время запуска:

# service dropbox start

У Dropbox существует консольная утилиты — dropbox.py, я ее тоже скачаю т.к она необходима:

# wget http://www.dropbox.com/download?dl=packages/dropbox.py -O /root/.dropbox-dist/dropbox.py && chmod +x /root/.dropbox-dist/dropbox.py

Для помощи, используем:

# /root/.dropbox-dist/dropbox.py help

Чтобы все бэкапы автоматически подгружались в dropbox необходимо выполнить линковку для каталогов:

# ln -s /var/backup-manager /root/Dropbox/backup

Чтобы запустить клиентскую часть, используйте:

# /root/.dropbox-dist/dropboxd &

Открываем в браузере ваш аккаунт в dropbox и смотрим бекапы:

dropbox в бекапы

dropbox в бекапы

Моя тема «Сохраняем все резервные копии в Dropbox» завершена. Скоро будет статья как можно создать подобные бэкапы в Google Drive/Yandex.Диск.

 

The post Сохраняем все резервные копии в Dropbox first appeared on linux-notes.org.]]>
https://linux-notes.org/sohranyaem-vse-rezervny-e-kopii-v-dropbox/feed/ 1
Page_c76a3fcf https://linux-notes.org/upravlenie-virtualbox-s-veb-interfejsom-phpvirtualbox/ https://linux-notes.org/upravlenie-virtualbox-s-veb-interfejsom-phpvirtualbox/#respond Mon, 09 Feb 2015 23:49:51 +0000 http://linux-notes.org/?p=5418 Управление VirtualBox с веб-интерфейсом phpVirtualBox phpVirtualBox является ПО с открытым исходным кодом,  который предоставляет веб-интерфейс для Oracle VirtualBox, написанной на PHP с реализацией AJAX. Она позволяет удаленно управлять экземплярами VirtualBox, действительно полезно, когда вы не имеете графического интерфейса в операционной системе. phpVirtualBox позволяет контролировать и управлять гостевыми экземплярами в качестве VirtualBox GUI и вы не найдете никакой […]

The post Управление VirtualBox с веб-интерфейсом phpVirtualBox first appeared on linux-notes.org.]]>

Управление VirtualBox с веб-интерфейсом phpVirtualBox

phpVirtualBox является ПО с открытым исходным кодом,  который предоставляет веб-интерфейс для Oracle VirtualBox, написанной на PHP с реализацией AJAX. Она позволяет удаленно управлять экземплярами VirtualBox, действительно полезно, когда вы не имеете графического интерфейса в операционной системе.

phpVirtualBox позволяет контролировать и управлять гостевыми экземплярами в качестве VirtualBox GUI и вы не найдете никакой разницы между веб-интерфейсом и VirtualBox GUI. Более того, phpVirtualBox поддерживает удаленную консоль через веб-клиент Oracle RDP , который поставляется с Extension Pack.

Вот небольшое руководство «Управление VirtualBox с веб-интерфейсом phpVirtualBox» для настройки phpVirtualBox на Ubuntu/Debian/Mint и CentOS/Fedora/RedHat (его поддерживает все Linux, его минимальным требованием является веб-сервер, установленный при поддержке PHP).

Установка Apache с PHP.

Установка apache+php в centOS

Установка apache+php в Debian/Ubuntu/Mint

Но БД не обязательно устанавливать в этом примере, можно выполнить:

$ sudo apt-get install apache2 php5 libapache2-mod-php5

Установка VirtualBox.

Как установить Virtualbox на Centos/Fedora

Как установить Virtualbox на Debian/Ubuntu/Mint

Скачиваем последнюю версию phpVirtualBox.

Выполните следующую команду, чтобы загрузить самую последнюю phpVirtualBox (на момент написания была версия 4.3.2):

$ cd /usr/local/src && wget 'http://sourceforge.net/projects/phpvirtualbox/files/latest/download'

Распаковываем:

$ sudo unzip phpvirtualbox-*.zip

Переместите этот документ в корень вашего веб-сервера (если изменили на свой, перемещаем на свой):

$ sudo mv phpvirtualbox-* /var/www/html/virtualbox

Конфигурация phpVirtualBox:

Мы должны изменить конфигурацию phpVirtualBox сделать успешную коммуникацию с установкой VirtualBox, сначала нужно переименовать файл образец конфигурации (config.php-пример в config.php).

$ sudo mv /var/www/html/virtualbox/config.php-example /var/www/html/virtualbox/config.php

Отредактируем ( изменим) файл-конфиг:

$ sudo nano /var/www/html/virtualbox/config.php

Ниже приведена минимальная конфигурация для phpVirtualBox. Имя пользователя / Пароль для системы, которая работает с VirtualBox, в моем случае я использую пользователя «captain» с некоторым паролем.

var $username = 'captain';
var $password = 'password_for_captain';

Если вы работаете с VirtualBox и PHP и они находятся на том же хосте, установите следующую опцию $location , как это показано ниже:

var $location = ‘http://127.0.0.1:18083/';

Конфигурация vboxweb-service.

Установка VirtualBox создает стартовый скрипт vboxweb-service, когда он установлен, то он используется для запуска и остановки vboxwebserv, перед запуском службы, мы должны иметь /etc/default/virtualbox и нужно создать его вручную, если он не существует.

$ sudo nano /etc/default/virtualbox

Мы должны установить минимальную VBOXWEB_USER запустить vboxweb-служба, в настоящее время VirtualBox будет работать как «captain»; этот пользователь и пароль должны быть введены в phpVirtualBox конфигурационном файле.

VBOXWEB_USER=captain

Если вы работаете в phpVirtualBox в какой-то другом хосте, VBOXWEB_HOST нужно тоже установлены в том же файле, в данном случае phpVirtualBox будет общаться с vboxweb-службе по сети.

VBOXWEB_USER=captain

VBOXWEB_HOST=192.168.1.103

Перезапуск vboxweb-service.

$ sudo /etc/init.d/vboxweb-service restart

Сейчас откройте ваш браузер и перейдите к http://your_ip_address/virtualbox, и вас попросят ввести логин и пароль. Стандартный логин и пароль — admin /admin.

Управление VirtualBox с веб-интерфейсом phpVirtualBox завершено.

The post Управление VirtualBox с веб-интерфейсом phpVirtualBox first appeared on linux-notes.org.]]>
https://linux-notes.org/upravlenie-virtualbox-s-veb-interfejsom-phpvirtualbox/feed/ 0
Page_c76a3fcf https://linux-notes.org/kak-ustanovit-virtualbox-na-centos-fedora/ https://linux-notes.org/kak-ustanovit-virtualbox-na-centos-fedora/#comments Mon, 23 Jun 2014 23:14:25 +0000 http://linux-notes.org/?p=2721 Установить Virtualbox на Centos/Fedora VirtualBox является приложением для виртуализации. Что это значит? С одной стороны, он устанавливается на реальный ПК  который работает на Windows, Mac или Linux. Во-вторых, это расширяет возможности существующего ПК, чтобы он мог запустить несколько операционных систем (внутри нескольких виртуальных машин) одновременно. Так, например, вы можете запустить венду и Linux на вашем ноутбуке или ПК, или можно запустить Windows Server […]

The post Установить Virtualbox на Centos/Fedora first appeared on linux-notes.org.]]>

Установить Virtualbox на Centos/Fedora

VirtualBox является приложением для виртуализации. Что это значит? С одной стороны, он устанавливается на реальный ПК  который работает на Windows, Mac или Linux. Во-вторых, это расширяет возможности существующего ПК, чтобы он мог запустить несколько операционных систем (внутри нескольких виртуальных машин) одновременно. Так, например, вы можете запустить венду и Linux на вашем ноутбуке или ПК, или можно запустить Windows Server 2012 на сервере Linux и так далее. Это весьма очень  удобно, не всегда хочешь ставить какую то ОС на свой реальный ноутбук или ПК, а хочется все таки посмотреть что и как ( хочешь пощупать). В своей теме «Установить Virtualbox на Centos/Fedora» я расскажу как можно установить Virtualbox на Centos/Fedora.

Установите некоторые зависимости, чтобы иметь полностью функциональный VirtualBox:

# yum install binutils qt gcc make patch libgomp glibc-headers glibc-devel kernel-headers kernel-devel dkms

Установка Virtualbox на Centos.

Установим дополнительное ПО:

# yum groupinstall "Development Tools" -y

Для начала добавим репозиторий:

# wget http://download.virtualbox.org/virtualbox/rpm/rhel/virtualbox.repo -O /etc/yum.repos.d/virtualbox.repo

После чего нужно обновить список всех имеющихся репозиториев, для этого нужно выполнить:

# yum update

Нужно установить следующие пакеты зависимостей. Для CentOS 6/5 и Red Hat (RHEL) 6/5 необходим репозиторий EPEL: Как включить EPEL репозиторий на CentOS

Для начала, смотрим какие версии имеются с виртуалбоксом:

# yum search VirtualBox

Loaded plugins: fastestmirror
Loading mirror speeds from cached hostfile
 * base: mirror.besthosting.ua
 * extras: mirror.besthosting.ua
 * updates: mirror.besthosting.ua
=========================== N/S matched: VirtualBox ============================
VirtualBox-4.3.x86_64 : Oracle VM VirtualBox
VirtualBox-5.0.x86_64 : Oracle VM VirtualBox
VirtualBox-5.1.x86_64 : Oracle VM VirtualBox

  Name and summary matches only, use "search all" for everything.
[root@localhost ~]# 

Как видно, что можно установить несколько версий, я буду использовать самую последнюю.

После всего этого можно устанавливать сам виртуалбокс, для этого:

# yum install VirtualBox-5.1 -y

Замените имя_пользователя с вашим собственным именем пользователя или другое реальное имя пользователя.

# usermod -aG vboxusers имя_пользователя

Чтобы запустить выполните:

# VirtualBox

Поиск неисправностей 

Если у вас есть проблемы с параметром KERN_DIR или ваш каталог ядра не определяется автоматически установите переменную окружения KERN_DIR вручную, используя следующий метод:

## Текущее работающее ядро (kernel) на CentOS /Red Hat##
KERN_DIR=/usr/src/kernels/`uname -r`-`uname -m`

## Пример использования на CentOS /Red Hat##
KERN_DIR=/usr/src/kernels/3.2.11-x86_64

## Экспортируем KERN_DIR ##
export KERN_DIR

Установка Virtualbox на Fedora 

1. Первое что нужно сделать, так это добавить репозиторий VirtualBox в хранилище (добавить в репозиторий):

# cd /etc/yum.repos.d && wget http://download.virtualbox.org/virtualbox/rpm/fedora/virtualbox.repo

2. Нужно обновить теперь список репозиториев, для того чтобы обновился только что добавленный репозиторий виртуалбокс, для этого:

# yum update

3. Установка виртуалбокса, для этого выполните:

# yum install VirtualBox

Эта команда должна установить самую последнюю версию программы, но если не получится это сделать, просто выполните команду и установите версию 4.3:

# yum install VirtualBox-4.3

Поиск неисправностей 

Если у вас есть проблемы с параметром KERN_DIR или ваш каталог ядра не определяется автоматически установите переменную окружения KERN_DIR вручную, используя следующий метод:

## Текущее работающее ядро (kernel) на Fedora ##
KERN_DIR=/usr/src/kernels/`uname -r`

## Пример использования на Fedora##
KERN_DIR=/usr/src/kernels/3.2.11.i686

## Экспортируем KERN_DIR ##
export KERN_DIR

ВСЕ! Можете пользоваться, а на этом я завершу «Как установить Virtualbox на Centos/Fedora «. Спасибо что посещаете и читаете мой сайт.

The post Установить Virtualbox на Centos/Fedora first appeared on linux-notes.org.]]>
https://linux-notes.org/kak-ustanovit-virtualbox-na-centos-fedora/feed/ 2